==> kafka-4.0.1-src.tgz: kafka-4.0.1-src/clients/src/main/java/org/apache/kafka/common/requests/RemoveRaftVoterRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.common.requests;

import org.apache.kafka.common.message.RemoveRaftVoterRequestData;
import org.apache.kafka.common.message.RemoveRaftVoterResponseData;
import org.apache.kafka.common.protocol.ApiKeys;
import org.apache.kafka.common.protocol.ByteBufferAccessor;
import org.apache.kafka.common.protocol.Errors;

import java.nio.ByteBuffer;

public class RemoveRaftVoterRequest extends AbstractRequest {
    public static class Builder extends AbstractRequest.Builder<RemoveRaftVoterRequest> {
        private final RemoveRaftVoterRequestData data;

        public Builder(RemoveRaftVoterRequestData data) {
            super(ApiKeys.REMOVE_RAFT_VOTER);
            this.data = data;
        }

        @Override
        public RemoveRaftVoterRequest build(short version) {
            return new RemoveRaftVoterRequest(data, version);
        }

        @Override
        public String toString() {
            return data.toString();
        }

    }

    private final RemoveRaftVoterRequestData data;

    public RemoveRaftVoterRequest(RemoveRaftVoterRequestData data, short version) {
        super(ApiKeys.REMOVE_RAFT_VOTER, version);
        this.data = data;
    }

    @Override
    public RemoveRaftVoterRequestData data() {
        return data;
    }

    @Override
    public AbstractResponse getErrorResponse(int throttleTimeMs, Throwable e) {
        Errors error = Errors.forException(e);
        return new RemoveRaftVoterResponse(new RemoveRaftVoterResponseData().
            setErrorCode(error.code()).
            setErrorMessage(error.message()).
            setThrottleTimeMs(throttleTimeMs));
    }

    public static RemoveRaftVoterRequest parse(ByteBuffer buffer, short version) {
        return new RemoveRaftVoterRequest(
            new RemoveRaftVoterRequestData(new ByteBufferAccessor(buffer), version),
            version);
    }
}

==> kafka-4.2.0-src.tgz: kafka-4.2.0-src/clients/src/main/java/org/apache/kafka/common/requests/RemoveRaftVoterRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.common.requests;

import org.apache.kafka.common.message.RemoveRaftVoterRequestData;
import org.apache.kafka.common.message.RemoveRaftVoterResponseData;
import org.apache.kafka.common.protocol.ApiKeys;
import org.apache.kafka.common.protocol.Errors;
import org.apache.kafka.common.protocol.Readable;

public class RemoveRaftVoterRequest extends AbstractRequest {
    public static class Builder extends AbstractRequest.Builder<RemoveRaftVoterRequest> {
        private final RemoveRaftVoterRequestData data;

        public Builder(RemoveRaftVoterRequestData data) {
            super(ApiKeys.REMOVE_RAFT_VOTER);
            this.data = data;
        }

        @Override
        public RemoveRaftVoterRequest build(short version) {
            return new RemoveRaftVoterRequest(data, version);
        }

        @Override
        public String toString() {
            return data.toString();
        }

    }

    private final RemoveRaftVoterRequestData data;

    public RemoveRaftVoterRequest(RemoveRaftVoterRequestData data, short version) {
        super(ApiKeys.REMOVE_RAFT_VOTER, version);
        this.data = data;
    }

    @Override
    public RemoveRaftVoterRequestData data() {
        return data;
    }

    @Override
    public AbstractResponse getErrorResponse(int throttleTimeMs, Throwable e) {
        Errors error = Errors.forException(e);
        return new RemoveRaftVoterResponse(new RemoveRaftVoterResponseData().
            setErrorCode(error.code()).
            setErrorMessage(error.message()).
            setThrottleTimeMs(throttleTimeMs));
    }

    public static RemoveRaftVoterRequest parse(Readable readable, short version) {
        return new RemoveRaftVoterRequest(
            new RemoveRaftVoterRequestData(readable, version),
            version);
    }
}
